@@ -1,7 +1,7 @@
 """
 ! Name: IntellgentStart.py
 ! Author: lolisky
-! Date: 2022-04-22
+! Date: 2022-05-02
 
 功能：基于切换连接进行的循环通信
      接收网关发来的智能场景信息
@@ -9,11 +9,11 @@
      分析视频画面人物动作
      发回给网关 场景触发信息
 """
+
 import socket
 import requests
 import json
 import time
-import multiprocessing
 import cv2
 import re
 import mediapipe as mp
@@ -99,7 +99,7 @@ def listening_deal(antenna, mylist):
             print("Listening Wrong")
 
 # 智能分析进程
-def processing_deal(mylist,wthlist):
+def processing_deal(mylist, wthlist, send_port):
     wth = wthlist[0]  # 天气状态
     # 默认地址（后续根据网关指令更改）
     # cap = cv2.VideoCapture("rtsp://wowzaec2demo.streamlock.net/vod/mp4:BigBuckBunny_115k.mp4")
@@ -108,7 +108,7 @@ def processing_deal(mylist,wthlist):
     while 1:
         antenna_send = socket.socket()
         try:
-            antenna_send.connect(('127.0.0.1', 6667))
+            antenna_send.connect(('127.0.0.1', send_port))
         except:
             print("初始化连接失败，再次发送……")
             continue
@@ -123,9 +123,18 @@ def processing_deal(mylist,wthlist):
         scenecount = len(mc.scenes)
         print(scenecount)
         if old != mc.addres:
-            print("修改流地址了")
+            print("修改流地址……(预计耗时1s)")
+            print("修改为：" + mc.addres)
+            # while 1:
+            #     try:
+            #         cap = cv2.VideoCapture(mc.addres)
+            #     except:
+            #         print("获取流失败，重新获取……")
+            #         continue
+            time.sleep(1)
             cap = cv2.VideoCapture(mc.addres)
             old = mc.addres
+            print("修改完毕")
         flag_valid_time = 0     # 时间有效位标志，看看该时间段是否符合各个场景的限制，符合则进入（置为1），不符合则不进行算法识别
         flag_valid_weather = 0  # 天气有效位标志，看看该时间天气是否满足用户设定，符合则置1，不符合则不进行算法识别
         valid_time_set = []
@@ -144,7 +153,7 @@ def processing_deal(mylist,wthlist):
                     valid_time_set.append(1)
                 else:
                     valid_time_set.append(0)
-                if (wth.DWeather == s.DWeather):
+                if (wth.DWeather == s.DWeather or s.DWeather == -1):
                     flag_valid_weather = 1
                     valid_weather_set.append(1)
                 else:
@@ -419,9 +428,9 @@ def processing_deal(mylist,wthlist):
 
                 if (flag_appear == 1):
                     antenna_send = socket.socket()
-                    # antenna_send.connect(('192.168.31.52', 6667))
+                    # antenna_send.connect(('192.168.31.52', send_port))
                     try:
-                        antenna_send.connect(('127.0.0.1', 6667))
+                        antenna_send.connect(('127.0.0.1', send_port))
                         antenna_send.send(repr(rejson).encode('utf-8'))
                         antenna_send.close()
                     except:
@@ -437,14 +446,15 @@ def processing_deal(mylist,wthlist):
             cap = cv2.VideoCapture(old)
         except Exception as e:
             print("Othering.........")
+            print(e)
             time.sleep(1)
             print('错误类型是', e.__class__.__name__)
             print('错误明细是', e)
             print("Wrong in Processing !")
             antenna_send = socket.socket()
-            # antenna_send.connect(('192.168.31.52', 6667))
+            # antenna_send.connect(('192.168.31.52', send_port))
             try:
-                antenna_send.connect(('127.0.0.1', 6667))
+                antenna_send.connect(('127.0.0.1', send_port))
                 antenna_send.send("Wrong in Processing !".encode('utf-8'))
                 antenna_send.close()
             except:
@@ -482,7 +492,7 @@ def getweather():
     print(weather)
     print("Weather:" + text)
     print("temp:" + temp)
-    pattern = re.compile(r"['雨','雪','晴','云','雾','霾','沙']")
+    pattern = re.compile(r"['雨','雪','晴','阴', '云','雾','霾','沙']")
     result = pattern.findall(text)  # 0：晴天  1：雨天  2：雪天  3：雨雪  4：阴天  5：雾天  6：雾霾  7：沙尘
     text = -1
     if len(result) == 0:
@@ -529,7 +539,7 @@ def weather_deal(wthlist):
             wth.temp = temp
             wthlist[0] = wth
 
-def Start():
+def Start(bind_port = 6666, send_port = 6667):
     multiprocessing.freeze_support()
     print("开始程序...")
     mylist = multiprocessing.Manager().list()
@@ -543,10 +553,10 @@ def Start():
     wthlist.append(wth)
     antenna = socket.socket()  # 实例化套接字通讯对象
 
-    antenna.bind(('127.0.0.1', 6666))  # 存放套接字
+    antenna.bind(('127.0.0.1', bind_port))  # 存放套接字
     antenna.listen(5)  # 设置连接的个数
     p_recv = Process(target=listening_deal, args=([antenna, mylist]))
-    p_proc = Process(target=processing_deal, args=([mylist, wthlist]))
+    p_proc = Process(target=processing_deal, args=([mylist, wthlist, send_port]))
     p_weath = Process(target=weather_deal, args=([wthlist]))
     # p_proc = Process(target=processing_deal, args=([antenna_send, mylist]))
     p_recv.start()
@@ -556,3 +566,5 @@ def Start():
     p_proc.join()
     p_weath.join()
 
+if __name__ == '__main__':
+    Start()
\ No newline at end of file
